diff options
| author | eunhhu <[email protected]> | 2026-10-08 16:13:14 +0100 |
|---|---|---|
| committer | eunhhu <[email protected]> | 2026-10-08 16:13:14 +0100 |
| commit | ea79694ede16a9204d71a8effe638cf580666ed0 (patch) | |
| tree | 2d6695b650ae0d42305399110ff0f4a77eae7bbd /docs/research/108-one-value-every-path.md | |
| parent | 38f54aca6491eddfc706a80649e49a592340c6ba (diff) | |
| download | pure-ea79694ede16a9204d71a8effe638cf580666ed0.tar.gz pure-ea79694ede16a9204d71a8effe638cf580666ed0.zip | |
041 runs of b12 = d371271 (four-byte MUL) and b13 = 38f54ac (reductions with no lanes while every lane's e is the same), interleaved with b11 and b12, and their counts: matmul 36.10 to 26.56 ms (instructions -20%), roots 8.82 to 8.31 (-6.1%), the executor alone as b9 on all five
Diffstat (limited to 'docs/research/108-one-value-every-path.md')
0 files changed, 0 insertions, 0 deletions
